#line 2 "tqmoc_lex.cpp"

#line 4 "tqmoc_lex.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 151
#define YY_END_OF_BUFFER 152
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[624] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  152,  151,
      139,  150,  151,  139,  134,  146,  139,  146,  146,  105,
      105,  105,  105,  105,  139,  134,  148,  139,  113,  148,
      148,  148,  130,  148,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,  139,  134,  140,  139,  140,  140,  106,
      106,  106,  106,   15,   16,  139,  134,  141,  139,  141,
      141,  107,  107,  107,  107,  107,   28,   29,  139,  134,

      145,  139,   54,   55,   58,  145,   59,   56,   57,   60,
      139,  134,  143,  139,   42,   43,   46,  143,   47,   44,
       45,  139,  134,  144,  139,   48,   49,   52,  144,   53,
       50,   51,  139,  134,  142,  139,  111,  142,   13,   14,
      139,  134,  137,  137,  112,   61,   62,  137,  137,  134,
      149,  139,  149,  139,  134,  147,  139,  147,  139,  134,
       34,   35,  100,  100,  100,  100,  100,  104,  101,  102,
      103,  139,  136,  135,  139,  134,  134,  134,    0,  108,
        0,  105,  105,  105,  105,  105,  113,    0,    0,  123,
        0,    0,  132,  131,  130,   92,   99,   99,   99,   99,

       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,    0,  109,
        0,  106,  106,  106,  106,  106,    0,  110,    0,  107,
      107,  107,  107,  107,  111,    0,  138,  112,    0,  138,
      100,  100,  100,  100,  100,  100,  104,    0,  135,  134,
      105,  105,  105,  105,  114,    0,    0,  114,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   93,
      131,   99,   99,   87,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   76,   99,   99,   99,   99,   99,

       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,  106,  106,  106,
      106,  106,  107,  107,  107,  107,  100,  100,  100,  100,
      100,  100,  134,  105,  105,  105,  105,  129,  125,  124,
      126,    0,  127,  122,  115,  116,  117,  118,  119,  120,
      121,    0,   99,   99,   99,   99,   99,   99,   65,   74,
       99,   99,   99,   83,   99,   99,   99,   99,   77,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   82,
       99,  106,  106,  106,  106,  106,  106,  106,  106,  106,

      106,  107,  107,  107,  107,  100,   36,  100,  100,  100,
      100,  134,    1,  105,  105,    3,  127,  128,   99,   99,
       99,   99,   99,   99,   99,   84,   72,   99,   99,   80,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   75,
       99,   99,   99,   99,   96,   99,   99,   99,   86,   99,
       97,   99,   99,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,   30,  107,  107,   33,  100,   39,
      100,  100,   37,  134,  105,  105,   99,   99,   99,   99,
       99,   99,   99,   81,   68,   63,   69,   99,   99,   99,
       99,   99,   90,   99,   78,   67,   85,   99,   99,   99,

       99,   99,   99,   99,  106,  106,  106,  106,  106,  106,
      106,  106,   17,  106,  106,  107,  107,  100,  100,   38,
      134,  105,  105,   99,   99,   99,   99,   99,   12,   99,
       95,   99,   99,   88,   99,   99,   99,   99,    7,   64,
       99,   71,   99,  106,  106,  106,  106,  106,   27,   19,
      106,  106,   21,  107,  107,  100,  100,  134,  134,  105,
        4,   99,   11,   99,   99,   99,   99,   99,   91,   99,
       66,   94,   99,   79,   73,  106,   26,  106,  106,  106,
      106,  106,  107,   31,  100,  100,  133,    2,   99,    5,
       99,   99,   99,   98,   89,    6,  106,   23,  106,  106,

       18,   20,   32,  100,  100,   99,   99,   99,   70,  106,
      106,  106,   40,   41,   99,   10,    9,  106,   25,   24,
        8,   22,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    3,    4,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    1,    5,    6,    1,    1,    1,    7,    8,
        9,   10,    1,   11,    1,   12,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,   17,   18,   19,
        1,   20,    1,    1,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   28,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   28,   43,   28,
       44,   45,   46,    1,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   28,   28,   57,   58,   59,
       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   28,   71,    1,   72,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[73] =
    {   0,
        1,    1,    1,    2,    3,    1,    4,    1,    1,    1,
        1,    1,    1,    5,    5,    5,    1,    1,    1,    1,
        5,    5,    5,    5,    5,    5,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    1,    1,    1,    6,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[651] =
    {   0,
        0,    3,   16,    5,   88,    9,  160,  232,  304,  178,
      375,  446,  183,  517,  252,  562,  209,  213,  607,  652,
      255,  286,  270,  388,  698,  187,  394,  407, 1202, 1203,
      180, 1203,  185,  379, 1150, 1203,  186,  219,  187,    0,
     1143, 1151, 1146, 1133,  420, 1145, 1203,  200, 1150,  221,
      413,  197,  418, 1177,    0, 1157, 1145,  203,  380, 1131,
      161,  237, 1131, 1129, 1122, 1139, 1125,  216, 1133,  386,
      391,  227,  344,  460, 1133, 1203,  206,  257,  404,    0,
     1147,  373, 1120, 1203, 1203,  465, 1130, 1203,  442,  433,
      459,    0, 1123, 1131, 1126, 1113, 1203, 1203,  471, 1125,

     1203,  473, 1203, 1203, 1203,  469, 1203, 1203, 1203, 1203,
      478, 1124, 1203,  483, 1203, 1203, 1203,  478, 1203, 1203,
     1203,  491, 1123, 1203,  493, 1203, 1203, 1203,  488, 1203,
     1203, 1203,  497, 1122, 1203,  502, 1127,  496, 1203, 1203,
      505, 1120, 1203,  510, 1125, 1203, 1203,  504,  530, 1118,
     1203,  513,  514,  535, 1117, 1203,  537,  521,  540, 1116,
     1203, 1203,    0, 1141, 1140,  385, 1127, 1118, 1203, 1203,
     1203,  542, 1203,    0,  545,    0,    0, 1110,  465, 1203,
     1157,    0, 1112, 1101, 1100, 1101, 1111,  545, 1148, 1147,
      766, 1141,  538,  541,  562, 1203,    0, 1105, 1095, 1092,

     1084, 1100, 1099, 1087, 1079, 1078, 1078, 1082, 1085,  230,
     1081, 1074, 1080, 1085,  400, 1087, 1081, 1074, 1079,  332,
     1074, 1068, 1066, 1068,  503, 1072, 1064,  525,  484, 1203,
     1122,    0, 1078,  427, 1075, 1059,  517, 1203, 1118,    0,
     1073, 1062, 1061, 1062, 1072,  579,  583, 1071,  583,  587,
        0, 1077,  368, 1077, 1079, 1083, 1066,  587,    0, 1057,
     1045, 1056, 1046, 1047, 1203, 1098, 1097, 1096,  587,  589,
     1095, 1094, 1093, 1092, 1091, 1090, 1089, 1088, 1087, 1203,
      583,  594, 1034,    0, 1032, 1028, 1026, 1025, 1039, 1029,
     1034, 1037, 1032, 1027,    0, 1028, 1033, 1028, 1016, 1011,

     1012, 1019, 1019, 1011, 1014, 1007, 1005, 1009, 1009,  557,
     1016, 1007, 1010, 1006,  999, 1012, 1014,  599,  994,  995,
     1002,  574,  994, 1005,  995,  996, 1025, 1029, 1027, 1022,
     1013, 1010,  992,  983,  982,  988,  990, 1203, 1203, 1203,
     1203,  628, 1203, 1203, 1203, 1203, 1203, 1203, 1203, 1203,
     1203, 1036, 1011, 1008,  538, 1003, 1014,  981,    0,    0,
      973,  971,  978,    0,  971,  968,  973,  972,    0,  981,
      965,  980,  979,  974,  969,  960,  958,  970,  965,  970,
      962,  950,  963,  956,  964,  955,  959,  958,  945,    0,
      945,  978,  975,  599,  970,  981,  957,  952,  947,  948,

      941,  936,  935,  941,  943,  969,    0,  956,  959,  968,
      967,  932,    0,  929,  941,    0, 1203, 1203,  967,  947,
      956,  960,  950,  944,  926,    0,    0,  929,  921,    0,
      928,  926,  920,  915,  910,  909,  919,  911,  890,    0,
      899,  899,  877,  893,    0,  877,  870,  875,    0,  860,
        0,  863,  850,  884,  857,  861,  809,  798,  791,  763,
      777,  776,  765,  758,    0,  761,  773,    0,  787,    0,
      779,  793,    0,  764,  765,  747,  772,  777,  783,  770,
      771,  767,  745,    0,    0,    0,    0,  751,  754,  741,
      748,  734,    0,  746,    0,    0,    0,  732,  748,  731,

      741,  741,  735,  734,  752,  757,  763,  750,  751,  747,
      732,  718,    0,  734,  715,  730,  712,  755,  754,    0,
      729,  722,  645,  657,  656,  670,  655,  666,    0,  638,
        0,  639,  625,    0,  635,  623,  633,  627,    0,    0,
      632,    0,  630,  643,  642,  656,  641,  652,    0,    0,
      624,  618,    0,  624,  621,  648,  647,  623,  591,  615,
        0,  637,    0,  625,  634,  625,  612,  600,    0,  599,
        0,    0,  585,    0,    0,  619,    0,  608,  617,  608,
      593,  577,  587,    0,  607,  594, 1203,    0,  590,    0,
      594,  568,  558,    0,    0,    0,  567,    0,  548,  530,

        0,    0,    0,  533,  477,  439,  433,  388,    0,  361,
      276,  232,    0,    0,  219,    0,    0,  189,    0,    0,
        0,    0, 1203,  835,  841,  847,  853,  859,  865,  871,
      877,  883,  889,  895,  897,  903,  909,  911,  917,  919,
      925,  927,  933,  939,  941,  947,  953,  959,  962,  967
    } ;

static yyconst flex_int16_t yy_def[651] =
    {   0,
      624,  624,  623,    3,  623,    5,  625,  625,  623,    9,
      626,  626,  627,  627,  628,  628,  629,  629,  630,  630,
      631,  631,  632,  632,  623,   25,  624,  624,  623,  623,
      623,  623,  623,  623,  633,  623,  623,  634,  623,  635,
      635,  635,  635,  635,  623,  633,  623,  623,  636,  637,
      623,  623,  623,  623,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  623,  633,  623,  623,  639,  623,  640,
      640,  640,  640,  623,  623,  623,  633,  623,  623,  641,
      623,  642,  642,  642,  642,  642,  623,  623,  623,  633,

      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  633,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  633,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  633,  623,  623,  643,  623,  623,  623,
      623,  633,  623,  623,  644,  623,  623,  623,  623,  633,
      623,  623,  623,  623,  633,  623,  623,  623,  623,  633,
      623,  623,  645,  645,  645,  645,  645,  646,  623,  623,
      623,  623,  623,  647,  623,  633,  633,  633,  634,  623,
      634,  635,  635,  635,  635,  635,  636,  636,  623,  623,
      648,  623,  623,  623,  623,  623,  638,  638,  638,  638,

      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  639,  623,
      639,  640,  640,  640,  640,  640,  641,  623,  641,  642,
      642,  642,  642,  642,  643,  643,  623,  644,  644,  623,
      645,  645,  645,  645,  645,  645,  646,  646,  647,  633,
      635,  635,  635,  635,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  649,  623,
      623,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,

      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  640,  640,  640,
      640,  640,  642,  642,  642,  642,  645,  645,  645,  645,
      645,  645,  633,  635,  635,  635,  635,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  649,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  640,  640,  640,  640,  640,  640,  640,  640,  640,

      640,  642,  642,  642,  642,  645,  645,  645,  645,  645,
      645,  633,  635,  635,  635,  635,  623,  623,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  642,  642,  642,  642,  645,  645,
      645,  645,  645,  633,  635,  635,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,

      638,  638,  638,  638,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  642,  642,  645,  645,  645,
      650,  635,  635,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  642,  642,  645,  645,  650,  650,  635,
      635,  638,  638,  638,  638,  638,  638,  638,  638,  638,
      638,  638,  638,  638,  638,  640,  640,  640,  640,  640,
      640,  640,  642,  642,  645,  645,  623,  635,  638,  638,
      638,  638,  638,  638,  638,  638,  640,  640,  640,  640,

      640,  640,  642,  645,  645,  638,  638,  638,  638,  640,
      640,  640,  645,  645,  638,  638,  638,  640,  640,  640,
      638,  640,    0,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623
    } ;

static yyconst flex_int16_t yy_nxt[1276] =
    {   0,
      623,   31,   31,   32,   31,   34,   32,   45,   35,  623,
       46,   74,   33,  623,   75,   33,   36,   37,   37,   32,
       38,   36,   36,   36,   36,   36,   36,   36,   39,   36,
       36,   36,   36,   36,   36,   36,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   36,
       36,   36,   40,   40,   40,   41,   40,   40,   40,   40,
       40,   40,   40,   40,   42,   40,   40,   40,   40,   40,
       43,   44,   40,   40,   40,   40,   36,   36,   47,   48,
       48,   32,   49,   47,   50,   47,   47,   47,   47,   51,

       52,   53,   53,   53,   54,   47,   47,   47,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   56,   55,   55,   55,
       55,   47,   47,   47,   57,   58,   55,   59,   60,   61,
       62,   55,   55,   63,   64,   65,   66,   67,   68,   55,
       69,   70,   71,   72,   73,   55,   55,   55,   47,   47,
       76,   77,   77,   32,   78,   76,   76,   76,   76,   76,
       76,   76,   79,   76,   76,   76,   76,   76,   76,   76,
       99,  172,  172,  100,  114,  114,   32,  172,  172,   34,
      115,  116,   35,  117,  173,  118,  173,  174,   81,  174,

      119,  172,  172,   76,   76,   76,  173,  172,  172,  174,
      136,  136,   32,  137,  136,  141,   32,  137,  142,  206,
       82,  138,  622,  180,   83,  138,  120,  190,  121,  207,
       84,   85,   76,   77,   86,   32,   78,   87,   76,   76,
       76,   76,   76,   76,   79,   76,   76,   76,   76,   76,
       76,   76,  621,  125,  125,   32,  152,  152,   32,  126,
      127,  230,  128,  181,  129,  191,  200,  153,  201,  130,
       81,  157,  157,   32,  620,   76,   76,   76,  215,  139,
      140,  216,  158,  139,  140,  225,  294,  152,  154,   32,
      226,  155,   82,  208,  295,  131,   83,  132,  153,  209,

      619,  231,   84,   85,   88,   89,   89,   32,   90,   88,
       88,   88,   88,   88,   88,   88,   91,   88,   88,   88,
       88,   88,   88,   88,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   92,   92,   92,   88,   88,   88,
       92,   92,   92,   93,   92,   92,   92,   92,   92,   92,
       92,   92,   94,   92,   92,   92,   92,   92,   95,   96,
       92,   92,   92,   92,   97,   98,  102,  102,   32,  306,
      172,  175,  103,  104,  176,  105,  618,  106,  328,  157,
      159,   32,  107,  160,  307,   31,   31,   32,  168,  227,

      158,  169,  170,  228,  171,  329,   33,  254,   31,   34,
       32,  168,   35,  173,  169,  170,  174,  171,  108,   33,
      109,  172,  175,  255,  192,  176,  193,  193,  193,  194,
      617,  195,  195,  195,  202,  234,  203,  238,  235,  204,
      218,  219,  221,  172,  172,  222,  110,  102,  111,   32,
      220,  112,  223,  103,  104,  300,  105,  616,  106,  301,
      224,  172,  175,  107,  615,  176,  172,  175,  173,  180,
      176,  174,  172,  175,  172,  172,  176,  239,  173,  172,
      175,  174,  319,  176,  172,  172,  320,  173,  230,  108,
      174,  109,  172,  175,  172,  172,  176,  173,  172,  175,

      174,  614,  176,  172,  172,  173,  172,  175,  174,  181,
      176,  247,  247,  173,  172,  172,  174,  110,  114,  122,
       32,  238,  123,  173,  115,  116,  174,  117,  231,  118,
      173,  247,  250,  174,  119,  176,  172,  175,  172,  172,
      176,  172,  175,  172,  172,  176,  172,  175,  187,  187,
      176,  193,  193,  193,  281,  281,  281,  613,  312,  421,
      120,  239,  121,  125,  133,   32,  313,  134,  612,  126,
      127,  611,  128,  194,  129,  195,  195,  195,  422,  130,
      316,  317,  245,  245,  247,  247,  248,  248,  247,  250,
      257,  257,  176,  341,  587,  343,  281,  281,  281,  610,

      342,  342,  342,  342,  609,  131,  608,  132,  144,  144,
       32,  145,  383,  384,  146,  147,  353,  607,  354,  148,
      456,  392,  606,  393,  605,  146,  147,  355,  356,  400,
      401,  357,  394,  395,  417,  559,  396,  604,  603,  457,
      602,  342,  342,  601,  600,  599,  598,  597,  596,  595,
      146,  594,  147,  144,  149,   32,  145,  150,  593,  146,
      147,  592,  591,  590,  148,  589,  588,  559,  586,  585,
      146,  147,  584,  583,  582,  581,  580,  579,  578,  577,
      576,  575,  574,  573,  572,  571,  570,  569,  568,  567,
      566,  565,  564,  563,  562,  146,  561,  147,   30,   31,

       31,   32,   30,   30,   30,  161,  162,   30,   30,   30,
       33,   30,   30,   30,   30,   30,   30,   30,  163,  163,
      163,  164,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  165,  166,  163,  163,  163,  167,
      163,   30,   30,   30,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,   30,   30,
      267,  560,  268,  559,  557,  556,  555,  554,  553,  269,
      270,  552,  551,  550,  549,  548,  547,  546,  545,  544,
      543,  542,  541,  540,  539,  538,  537,  536,  535,  534,

      533,  532,  531,  530,  529,  528,  527,  526,  525,  524,
      271,  523,  522,  272,  273,  521,  520,  519,  274,  518,
      517,  516,  515,  514,  275,  513,  512,  511,  276,  510,
      277,  509,  278,  508,  279,   30,   30,   30,   30,   30,
       30,   80,   80,   80,   80,   80,   80,  101,  101,  101,
      101,  101,  101,  113,  113,  113,  113,  113,  113,  124,
      124,  124,  124,  124,  124,  135,  135,  135,  135,  135,
      135,  143,  143,  143,  143,  143,  143,  151,  151,  151,
      151,  151,  151,  156,  156,  156,  156,  156,  156,  177,
      507,  177,  177,  177,  177,  179,  506,  179,  179,  179,

      179,  182,  182,  187,  505,  504,  187,  187,  187,  189,
      503,  189,  189,  189,  189,  197,  197,  229,  502,  229,
      229,  229,  229,  232,  232,  237,  501,  237,  237,  237,
      237,  240,  240,  245,  500,  499,  245,  245,  245,  248,
      498,  497,  248,  248,  248,  251,  251,  257,  496,  495,
      257,  257,  257,  259,  494,  259,  259,  259,  259,  266,
      493,  266,  266,  266,  266,  352,  352,  558,  492,  558,
      558,  558,  558,  491,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  481,  480,  479,  478,  477,  476,  475,
      474,  473,  472,  471,  470,  469,  468,  467,  466,  465,

      464,  463,  462,  461,  460,  459,  458,  455,  454,  453,
      452,  451,  450,  449,  448,  447,  446,  445,  444,  443,
      442,  441,  440,  439,  438,  437,  436,  435,  434,  433,
      432,  431,  430,  429,  428,  427,  426,  425,  424,  423,
      420,  419,  418,  416,  415,  414,  413,  412,  411,  410,
      409,  408,  407,  406,  405,  404,  403,  402,  399,  398,
      397,  391,  390,  389,  388,  387,  386,  385,  382,  381,
      380,  379,  378,  377,  376,  375,  374,  373,  372,  371,
      370,  369,  368,  367,  366,  365,  364,  363,  362,  361,
      360,  359,  358,  338,  351,  350,  349,  348,  347,  346,

      345,  344,  340,  339,  338,  337,  336,  335,  334,  333,
      258,  332,  331,  330,  327,  249,  246,  326,  325,  324,
      323,  237,  322,  321,  318,  229,  315,  314,  311,  310,
      309,  308,  305,  304,  303,  302,  299,  298,  297,  296,
      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  282,  280,  265,  265,  188,  264,  263,  262,  261,
      179,  260,  258,  256,  253,  252,  178,  178,  178,  249,
      178,  246,  178,  178,  178,  178,  244,  243,  242,  241,
      178,  236,  233,  178,  217,  214,  213,  212,  211,  210,
      205,  199,  198,  196,  188,  178,  186,  185,  184,  183,

      178,  623,   29,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623
    } ;

static yyconst flex_int16_t yy_chk[1276] =
    {   0,
        0,    1,    1,    1,    2,    2,    2,    4,    2,    0,
        4,    6,    1,    0,    6,    2,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
       10,   31,   31,   10,   13,   13,   13,   37,   37,   26,
       13,   13,   26,   13,   33,   13,   39,   33,    7,   39,

       13,   48,   48,    7,    7,    7,   52,   77,   77,   52,
       17,   17,   17,   17,   18,   18,   18,   18,   18,   61,
        7,   17,  618,   38,    7,   18,   13,   50,   13,   61,
        7,    7,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,  615,   15,   15,   15,   21,   21,   21,   15,
       15,   78,   15,   38,   15,   50,   58,   21,   58,   15,
        8,   23,   23,   23,  612,    8,    8,    8,   68,   17,
       17,   68,   23,   18,   18,   72,  210,   22,   22,   22,
       72,   22,    8,   62,  210,   15,    8,   15,   22,   62,

      611,   78,    8,    8,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,   11,   11,   11,  220,
       34,   34,   11,   11,   34,   11,  610,   11,  253,   24,
       24,   24,   11,   24,  220,   27,   27,   27,   27,   73,

       24,   27,   27,   73,   27,  253,   27,  166,   28,   28,
       28,   28,   28,   79,   28,   28,   79,   28,   11,   28,
       11,   45,   45,  166,   51,   45,   51,   51,   51,   53,
      608,   53,   53,   53,   59,   82,   59,   90,   82,   59,
       70,   70,   71,   89,   89,   71,   11,   12,   12,   12,
       70,   12,   71,   12,   12,  215,   12,  607,   12,  215,
       71,   74,   74,   12,  606,   74,   86,   86,   91,  179,
       86,   91,   99,   99,  102,  102,   99,   90,  106,  111,
      111,  106,  234,  111,  114,  114,  234,  118,  229,   12,
      118,   12,  122,  122,  125,  125,  122,  129,  133,  133,

      129,  605,  133,  136,  136,  138,  141,  141,  138,  179,
      141,  144,  144,  148,  152,  152,  148,   12,   14,   14,
       14,  237,   14,  153,   14,   14,  153,   14,  229,   14,
      158,  149,  149,  158,   14,  149,  154,  154,  157,  157,
      154,  159,  159,  172,  172,  159,  175,  175,  188,  188,
      175,  193,  193,  193,  194,  194,  194,  604,  225,  355,
       14,  237,   14,   16,   16,   16,  225,   16,  600,   16,
       16,  599,   16,  195,   16,  195,  195,  195,  355,   16,
      228,  228,  246,  246,  247,  247,  249,  249,  250,  250,
      258,  258,  250,  269,  559,  270,  281,  281,  281,  597,

      269,  269,  270,  270,  593,   16,  592,   16,   19,   19,
       19,   19,  310,  310,   19,   19,  282,  591,  282,   19,
      394,  318,  589,  318,  586,   19,   19,  282,  282,  322,
      322,  282,  318,  318,  342,  559,  318,  585,  583,  394,
      582,  342,  342,  581,  580,  579,  578,  576,  573,  570,
       19,  568,   19,   20,   20,   20,   20,   20,  567,   20,
       20,  566,  565,  564,   20,  562,  560,  558,  557,  556,
       20,   20,  555,  554,  552,  551,  548,  547,  546,  545,
      544,  543,  541,  538,  537,  536,  535,  533,  532,  530,
      528,  527,  526,  525,  524,   20,  523,   20,   25,   25,

       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
      191,  522,  191,  521,  519,  518,  517,  516,  515,  191,
      191,  514,  512,  511,  510,  509,  508,  507,  506,  505,
      504,  503,  502,  501,  500,  499,  498,  494,  492,  491,

      490,  489,  488,  483,  482,  481,  480,  479,  478,  477,
      191,  476,  475,  191,  191,  474,  472,  471,  191,  469,
      467,  466,  464,  463,  191,  462,  461,  460,  191,  459,
      191,  458,  191,  457,  191,  624,  624,  624,  624,  624,
      624,  625,  625,  625,  625,  625,  625,  626,  626,  626,
      626,  626,  626,  627,  627,  627,  627,  627,  627,  628,
      628,  628,  628,  628,  628,  629,  629,  629,  629,  629,
      629,  630,  630,  630,  630,  630,  630,  631,  631,  631,
      631,  631,  631,  632,  632,  632,  632,  632,  632,  633,
      456,  633,  633,  633,  633,  634,  455,  634,  634,  634,

      634,  635,  635,  636,  454,  453,  636,  636,  636,  637,
      452,  637,  637,  637,  637,  638,  638,  639,  450,  639,
      639,  639,  639,  640,  640,  641,  448,  641,  641,  641,
      641,  642,  642,  643,  447,  446,  643,  643,  643,  644,
      444,  443,  644,  644,  644,  645,  645,  646,  442,  441,
      646,  646,  646,  647,  439,  647,  647,  647,  647,  648,
      438,  648,  648,  648,  648,  649,  649,  650,  437,  650,
      650,  650,  650,  436,  435,  434,  433,  432,  431,  429,
      428,  425,  424,  423,  422,  421,  420,  419,  415,  414,
      412,  411,  410,  409,  408,  406,  405,  404,  403,  402,

      401,  400,  399,  398,  397,  396,  395,  393,  392,  391,
      389,  388,  387,  386,  385,  384,  383,  382,  381,  380,
      379,  378,  377,  376,  375,  374,  373,  372,  371,  370,
      368,  367,  366,  365,  363,  362,  361,  358,  357,  356,
      354,  353,  352,  337,  336,  335,  334,  333,  332,  331,
      330,  329,  328,  327,  326,  325,  324,  323,  321,  320,
      319,  317,  316,  315,  314,  313,  312,  311,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  296,  294,  293,  292,  291,  290,  289,  288,  287,
      286,  285,  283,  279,  278,  277,  276,  275,  274,  273,

      272,  271,  268,  267,  266,  264,  263,  262,  261,  260,
      257,  256,  255,  254,  252,  248,  245,  244,  243,  242,
      241,  239,  236,  235,  233,  231,  227,  226,  224,  223,
      222,  221,  219,  218,  217,  216,  214,  213,  212,  211,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  192,  190,  189,  187,  186,  185,  184,  183,
      181,  178,  168,  167,  165,  164,  160,  155,  150,  145,
      142,  137,  134,  123,  112,  100,   96,   95,   94,   93,
       87,   83,   81,   75,   69,   67,   66,   65,   64,   63,
       60,   57,   56,   54,   49,   46,   44,   43,   42,   41,

       35,   29,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "tqmoc.l"
/****************************************************************************
**
** Lexical analyzer for meta object compiler
**
** Created : 930417
**
** Copyright (C) 2010 Timothy Pearson and (C) 1992-2008 Trolltech ASA.
**
** This file is part of the TQt GUI Toolkit.
**
** This file may be used under the terms of the GNU General
** Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the files LICENSE.GPL2
** and LICENSE.GPL3 included in the packaging of this file.
** Alternatively you may (at your option) use any later version
** of the GNU General Public License if such license has been
** publicly approved by Trolltech ASA (or its successors, if any)
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** This file may be used under the terms of the TQ Public License as
** defined by Trolltech ASA and appearing in the file LICENSE.TQPL
** included in the packaging of this file.  Licensees holding valid TQt
** Commercial licenses may use this file in accordance with the TQt
** Commercial License Agreement provided with the Software.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not granted
** herein.
**
*****************************************************************************/
#line 42 "tqmoc.l"
#ifdef TQMOC_YACC_CODE

#ifdef TQMOC_MWERKS_PLUGIN
#ifdef TQ_OS_MAC9
# define isascii(c)   ((int)( (unsigned int) (c) <= (unsigned char)0x7F ))
#endif
const char *buf_buffer = NULL;
long buf_size_total = 0, buf_index = 0;
#define YY_INPUT(buf, result, max_size) \
     { \
          if(buf_index < buf_size_total ) { \
              while(!isascii(buf_buffer[buf_index])) buf_index++; \
              int ms = ((max_size < buf_size_total) ? max_size : buf_size_total); \
              for(result = 0; result < ms; result++) { \
                 char c = buf_buffer[buf_index + result]; \
                 if(!isascii(c)) { \
                    buf_index++; \
                    break; \
                 } \
                 buf[result] = c == '\r' ? '\n' : c; \
              } \
              buf_index += result; \
          } else result = YY_NULL; \
     }
#endif

#include "tqstring.h"


#define input yyinput				// yyinput in C++

#define X if(lexDebug){fprintf(stderr,"LEX (%i) : %s\n",lineNo,yytext);};
#define Y if(lexDebug){fprintf(stderr,"LEX (%i) : %s\n",lineNo,yytext);};
/*
#define Y if(lexDebug){fprintf(stderr,"LEX (%i) : %s updates level to %i\n"\
                                 ,lineNo,yytext,templLevel);};
*/
#define Z if(lexDebug){fprintf(stderr,"LEX (%i) : skipped the string %s\"\n"\
                               ,lineNo,yytext);};
#define BEGIN_INSIDE


#define linput() \
    ( (c = input()) == '\n' ? (lineNo++, c) : (c == EOF) ? 0 : c )

#include <string.h>
#include <stdlib.h>

int classPLevel      = 1;  /* Depth of nested curly braces in IN_CLASS */
int namespacePLevel  = 1;  /* Depth of nested curly braces in IN_NAMESPACE */
int expLevel         = 1;  /* Depth of nested parentheses in IN_EXPR */
int enumLevel         = 1;  /* Depth of nested parentheses in IN_ENUM */
int fctLevel         = 1;  /* Depth of nested parentheses in IN_FCT */
int templLevel       = 1;  /* Depth of levels in IN_TEMPL_ARGS */

int lastState        = 0;  /* Remembers the state when a
                              TQMOC_SKIP_BEGIN is encountered */
int skipLevel        = 0; /* Depth of TQMOC_SKIP_BEGINs */

class TQString;

extern void addExpressionChar( const char );
extern void addExpressionString( const char * );
extern void tqmoc_warn( const char *msg );

#line 1057 "tqmoc_lex.cpp"

#define INITIAL 0
#define OUTSIDE 1
#define TQT_DEF 2
#define IN_CLASS 3
#define IN_NAMESPACE 4
#define IN_ENUM 5
#define IN_EXPR 6
#define IN_DEF_ARG 7
#define IN_FCT 8
#define IN_TEMPL_ARGS 9
#define GIMME_SEMICOLON 10
#define SKIP 11
#define IN_PROPERTY 12
#define IN_CLASSINFO 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 113 "tqmoc.l"


#line 1263 "tqmoc_lex.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 624 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1203 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 115 "tqmoc.l"
{ X;
				  BEGIN TQT_DEF;
				  return CLASS; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 118 "tqmoc.l"
{ X;
				  BEGIN TQT_DEF;
				  return NAMESPACE; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 121 "tqmoc.l"
{ X;
                                  BEGIN TQT_DEF;
				  return USING; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 124 "tqmoc.l"
{ X;
				  BEGIN TQT_DEF;
				  return TEMPLATE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 127 "tqmoc.l"
{ X; return TQ_OBJECT; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 128 "tqmoc.l"
{ X; return SIGNALS; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 129 "tqmoc.l"
{ X; return SLOTS; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 130 "tqmoc.l"
{ X; return TQ_CLASSINFO; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 131 "tqmoc.l"
{ X; return Q_PROPERTY; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 132 "tqmoc.l"
{ X; return TQ_OVERRIDE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 133 "tqmoc.l"
{ X; return TQ_ENUMS; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 134 "tqmoc.l"
{ X; return TQ_SETS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 136 "tqmoc.l"
{ fctLevel++;Y; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 137 "tqmoc.l"
{ fctLevel--;Y;if (fctLevel==0){X;return '}';}}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 138 "tqmoc.l"
{ classPLevel++;Y; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 139 "tqmoc.l"
{ classPLevel--;Y;if (classPLevel == 0)
                                                      {X;return '}';} }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 141 "tqmoc.l"
{ X;if( classPLevel == 1 ) return PUBLIC; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 142 "tqmoc.l"
{ X;if( classPLevel == 1 ) return PROTECTED; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 143 "tqmoc.l"
{ X;if( classPLevel == 1 ) return PRIVATE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 144 "tqmoc.l"
{ X;if( classPLevel == 1 ) return SIGNALS; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 145 "tqmoc.l"
{ X;if( classPLevel == 1 ) return SLOTS; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 146 "tqmoc.l"
{ X;if( classPLevel == 1 ) return TQ_CLASSINFO; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 147 "tqmoc.l"
{ X;
				  if ( classPLevel == 1 )
				      return TQ_OBJECT;
				  else if ( classPLevel > 1 )
				      tqmoc_warn( "Cannot use TQ_OBJECT in nested class." );
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 153 "tqmoc.l"
{ X;if( classPLevel == 1 ) return Q_PROPERTY; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 154 "tqmoc.l"
{ X;if( classPLevel == 1 ) return TQ_OVERRIDE; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 155 "tqmoc.l"
{ X;if( classPLevel == 1 ) return TQ_ENUMS; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 156 "tqmoc.l"
{ X;if( classPLevel == 1 ) return TQ_SETS; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 158 "tqmoc.l"
{ namespacePLevel++;Y; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 159 "tqmoc.l"
{ namespacePLevel--;Y;if (namespacePLevel == 0)
                                                          {X;return '}';}}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 161 "tqmoc.l"
{ X;
                                  BEGIN TQT_DEF;
				  return CLASS; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 164 "tqmoc.l"
{ X;
                                  BEGIN TQT_DEF;
                                  return TEMPLATE; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 167 "tqmoc.l"
{ X;
				  BEGIN TQT_DEF;
				  return NAMESPACE; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 170 "tqmoc.l"
{ X;
                                  BEGIN TQT_DEF;
				  return USING; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 174 "tqmoc.l"
{ X; return '('; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 175 "tqmoc.l"
{ X; return ')'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 176 "tqmoc.l"
{ X; return READ; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 177 "tqmoc.l"
{ X; return WRITE; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 178 "tqmoc.l"
{ X; return STORED; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 179 "tqmoc.l"
{ X; return RESET; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 180 "tqmoc.l"
{ X; return DESIGNABLE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 181 "tqmoc.l"
{ X; return SCRIPTABLE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 184 "tqmoc.l"
{ expLevel++;X; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 185 "tqmoc.l"
{ expLevel--;Y;if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ')';} }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 187 "tqmoc.l"
{ expLevel++;X; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 188 "tqmoc.l"
{ expLevel--;X;if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ']';} }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 190 "tqmoc.l"
{ if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ',' ;} }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 192 "tqmoc.l"
{ if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ';' ;} }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 194 "tqmoc.l"
{ expLevel++;X; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 195 "tqmoc.l"
{ expLevel--;Y;if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ')';} }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 197 "tqmoc.l"
{ expLevel++;X; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 198 "tqmoc.l"
{ expLevel--;X;if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ']';} }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 200 "tqmoc.l"
{ if (expLevel <= 1)
					{ X; BEGIN TQT_DEF; return ',' ;} }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 202 "tqmoc.l"
{ if (expLevel == 0)
					{ X; BEGIN TQT_DEF; return ';' ;} }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 204 "tqmoc.l"
{ enumLevel++;X; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 205 "tqmoc.l"
{ enumLevel--;X; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 206 "tqmoc.l"
{ enumLevel++;X; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 207 "tqmoc.l"
{ enumLevel--;X }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 208 "tqmoc.l"
{ if (enumLevel == 0)
					{ X; BEGIN TQT_DEF; return ',' ;} }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 210 "tqmoc.l"
{ if (enumLevel == 0)
					{ X; BEGIN TQT_DEF; return ';' ;} }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 212 "tqmoc.l"
{ if (enumLevel == 0)
					{ X; BEGIN TQT_DEF; return '}' ;} }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 214 "tqmoc.l"
{ templLevel++;
				  Y;
				  addExpressionChar( yytext[0] );
				}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 218 "tqmoc.l"
{ templLevel--;
				  Y;
				  if ( templLevel == 0 ) {
				      X;
				      BEGIN TQT_DEF;
				      return yytext[0];
				  } else {
				      addExpressionChar( yytext[0] );
				  }
				}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 228 "tqmoc.l"
{ X;return FRIEND; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 229 "tqmoc.l"
{ X;return TYPEDEF; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 230 "tqmoc.l"
{ X;return AUTO; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 231 "tqmoc.l"
{ X;return REGISTER; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 232 "tqmoc.l"
{ X;return STATIC; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 233 "tqmoc.l"
{ X;return EXTERN; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 234 "tqmoc.l"
{ X;return INLINE; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 235 "tqmoc.l"
{ X;return INLINE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 236 "tqmoc.l"
{ X;return VIRTUAL; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 237 "tqmoc.l"
{ X;return CONST; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 238 "tqmoc.l"
{ X;return VOLATILE; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 239 "tqmoc.l"
{ X;return CHAR; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 240 "tqmoc.l"
{ X;return SHORT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 241 "tqmoc.l"
{ X;return INT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 242 "tqmoc.l"
{ X;return LONG; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 243 "tqmoc.l"
{ X;return SIGNED; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 244 "tqmoc.l"
{ X;return UNSIGNED; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 245 "tqmoc.l"
{ X;return FLOAT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 246 "tqmoc.l"
{ X;return DOUBLE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 247 "tqmoc.l"
{ X;return VOID; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 248 "tqmoc.l"
{ X;return ENUM; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 249 "tqmoc.l"
{ X;return CLASS; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 250 "tqmoc.l"
{ X;return STRUCT; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 251 "tqmoc.l"
{ X;return UNION; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 252 "tqmoc.l"
{ X;return ASM; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 253 "tqmoc.l"
{ X;return PRIVATE; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 254 "tqmoc.l"
{ X;return PROTECTED; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 255 "tqmoc.l"
{ X;return PUBLIC; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 256 "tqmoc.l"
{ X;return OPERATOR; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 257 "tqmoc.l"
{ X;return DBL_COLON; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 258 "tqmoc.l"
{ X;return TRIPLE_DOT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 259 "tqmoc.l"
{ X;return TEMPLATE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 260 "tqmoc.l"
{ X;return MUTABLE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 261 "tqmoc.l"
{ X;return THROW; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 262 "tqmoc.l"
{ X;return USING; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 263 "tqmoc.l"
{ X;return NAMESPACE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 265 "tqmoc.l"
{
			  X;
			  yylval.string = qstrdup(yytext);
			  return IDENTIFIER;
			}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 271 "tqmoc.l"
{
			  X;
			  yylval.string = qstrdup(yytext);
			  return IDENTIFIER;
			}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 277 "tqmoc.l"
{ X; return '('; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 278 "tqmoc.l"
{ X; return ')'; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 279 "tqmoc.l"
{ X; return ','; }
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 281 "tqmoc.l"
{
			  X;
			  yylval.string = qstrdup( yytext + 1 );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 288 "tqmoc.l"
;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 289 "tqmoc.l"
;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 290 "tqmoc.l"
;
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
#line 292 "tqmoc.l"
{				/* discard strings */
			  Z;
			}
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 296 "tqmoc.l"
{				/* discard strings */
			  Z;
			}
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 300 "tqmoc.l"
{			/* discard strings */
			  Z;
			}
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 304 "tqmoc.l"
{			/* discard strings */
			  Z;
			  addExpressionString( yytext );
			  input();		/* discard the '"' */
			}
	YY_BREAK
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 311 "tqmoc.l"
{
			  X;
			  addExpressionString( yytext );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 318 "tqmoc.l"
{
			  X;
			  yylval.string = qstrdup( yytext + 1 );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 325 "tqmoc.l"
{ X;
			  yylval.char_val = yytext[1];
			  return CHAR_VAL;
			}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 330 "tqmoc.l"
{ X;
			 yylval.char_val = '\a';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 335 "tqmoc.l"
{ X;
			 yylval.char_val = '\b';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 340 "tqmoc.l"
{ X;
			 yylval.char_val = '\f';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 345 "tqmoc.l"
{ X;
			 yylval.char_val = '\n';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 350 "tqmoc.l"
{ X;
			 yylval.char_val = '\r';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 355 "tqmoc.l"
{ X;
			 yylval.char_val = '\t';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 360 "tqmoc.l"
{ X;
			 yylval.char_val = '\v';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 365 "tqmoc.l"
{ X;
			 yylval.char_val = '\\';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 370 "tqmoc.l"
{ X;
			 yylval.char_val = '\?';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 375 "tqmoc.l"
{ X;
			 yylval.char_val = '\'';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 380 "tqmoc.l"
{ X;
			 yylval.char_val = '\"';	/* " */
			 return CHAR_VAL;
		       }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 385 "tqmoc.l"
{ X;
			 yylval.char_val = '\0';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 390 "tqmoc.l"
{ X;
			 yylval.char_val =
			   (char)strtol( &yytext[1], 0, 8 );
			 return CHAR_VAL;
		       }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 396 "tqmoc.l"
{ X;
			 yylval.char_val =
			   (char)strtol( &yytext[2], 0, 16 );
			 return CHAR_VAL;
		       }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 402 "tqmoc.l"
{ X;
			 yylval.char_val = ' ';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 407 "tqmoc.l"
{ X;
			  yylval.int_val = atoi(yytext);
			  return INT_VAL;
			}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 412 "tqmoc.l"
{ X;
			  yylval.double_val = atof(yytext);
			  return DOUBLE_VAL;
			}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 417 "tqmoc.l"
{ X;
			  yylval.double_val = atof(yytext);
			  return DOUBLE_VAL;
			}
	YY_BREAK
case 133:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 423 "tqmoc.l"
{ /* skip multi-line macro-definitions */
			  int c, c1;
			  input();   /* Discard the '\n'. */
			  do {
			      c1=' ';
			      while((c = linput()) != '\n' && c != 0) c1=c;
			      if (c == 0) break;
			  } while(c1=='\\');
			  unput(c);  /* put back the '\n' or the EOF */
			}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 434 "tqmoc.l"
{ /* preprocessor commands are skipped */}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 435 "tqmoc.l"
{ /* C++ comment */
			  TQCString s = yytext;
                          if ( s.contains( "TQMOC_SKIP_BEGIN" ) ) {
                            skipLevel++;
                            if ( skipLevel == 1 ) {
                              lastState = YYSTATE;
                              BEGIN SKIP;
                            }
                          } else
                          if ( s.contains( "TQMOC_SKIP_END" ) ) {
                            if ( skipLevel == 0 ) {
                              tqmoc_warn(" TQMOC_SKIP_END without TQMOC_SKIP_BEGIN");
                            } else {
                              skipLevel--;
                              if ( skipLevel == 0 ) {
                                BEGIN lastState;
                              }
                            }
                          }
                        }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 455 "tqmoc.l"
{ /* C comment */
			  int c = ' ';
			  do {
			      if ( c!= '*' ) {
				  while((c = linput()) != '*' && c != 0)
				      ;
			      }
			      if (c == 0) break;
			  } while(((c = linput())) != '/' && c != 0);
			  if (c == 0)
			      unput(c);
			}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 468 "tqmoc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 470 "tqmoc.l"
{
				    /* spaces are important in template args,
				       e.g. Foo<const int> */
				    addExpressionChar( yytext[0] ); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 474 "tqmoc.l"
;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 475 "tqmoc.l"
;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 476 "tqmoc.l"
;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 477 "tqmoc.l"
;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 478 "tqmoc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 479 "tqmoc.l"
;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 480 "tqmoc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 481 "tqmoc.l"
;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 482 "tqmoc.l"
;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 483 "tqmoc.l"
{
			  X;
			  return yytext[0];
			}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 487 "tqmoc.l"
{
			  X;
			  return ';';
			}
	YY_BREAK
case 150:
/* rule 150 can match eol */
YY_RULE_SETUP
#line 491 "tqmoc.l"
{
			  lineNo++;
			}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 496 "tqmoc.l"
ECHO;
	YY_BREAK
#line 2301 "tqmoc_lex.cpp"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(OUTSIDE):
case YY_STATE_EOF(TQT_DEF):
case YY_STATE_EOF(IN_CLASS):
case YY_STATE_EOF(IN_NAMESPACE):
case YY_STATE_EOF(IN_ENUM):
case YY_STATE_EOF(IN_EXPR):
case YY_STATE_EOF(IN_DEF_ARG):
case YY_STATE_EOF(IN_FCT):
case YY_STATE_EOF(IN_TEMPL_ARGS):
case YY_STATE_EOF(GIMME_SEMICOLON):
case YY_STATE_EOF(SKIP):
case YY_STATE_EOF(IN_PROPERTY):
case YY_STATE_EOF(IN_CLASSINFO):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 624 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 624 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 623);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 496 "tqmoc.l"



#endif // TQMOC_YACC_CODE

